import React, { useState, useEffect, useCallback } from 'react';
import { DatePicker, ConfigProvider } from 'antd';
import dayjs from 'dayjs';
import classNames from 'classnames';
import styles from './index.less';

export type DateType = 'day' | 'month' | 'year' | 'range';

export interface DateSelectorProps {
  defaultType?: DateType;
  onChange?: (params: { type: DateType; startTime: string; endTime: string }) => void;
}

const DateSelector: React.FC<DateSelectorProps> = ({ 
  defaultType = 'day',
  onChange
}) => {
  const [activeType, setActiveType] = useState<DateType>(defaultType);
  const [dates, setDates] = useState<{
    startTime: string;
    endTime: string;
  }>(() => {
    if (defaultType === 'day') {
      return {
        startTime: dayjs().format('YYYY-MM-DD'),
        endTime: dayjs().format('YYYY-MM-DD')
      };
    } else if (defaultType === 'month') {
      return {
        startTime: dayjs().startOf('month').format('YYYY-MM-DD'),
        endTime: dayjs().endOf('month').format('YYYY-MM-DD')
      };
    } else if (defaultType === 'year') {
      return {
        startTime: dayjs().startOf('year').format('YYYY-MM-DD'),
        endTime: dayjs().endOf('year').format('YYYY-MM-DD')
      };
    } else {
      return {
        startTime: dayjs().format('YYYY-MM-DD'),
        endTime: dayjs().format('YYYY-MM-DD')
      };
    }
  });

  // Memoize the notification function to avoid recreating it on every render
  const notifyChange = useCallback(() => {
    if (onChange) {
      onChange({
        type: activeType,
        ...dates
      });
    }
  }, [activeType, dates, onChange]);

  // Effect to reset dates when activeType changes
  useEffect(() => {
    let newDates = { ...dates };
    
    if (activeType === 'day') {
      newDates = {
        startTime: dayjs().format('YYYY-MM-DD'),
        endTime: dayjs().format('YYYY-MM-DD')
      };
    } else if (activeType === 'month') {
      newDates = {
        startTime: dayjs().startOf('month').format('YYYY-MM-DD'),
        endTime: dayjs().endOf('month').format('YYYY-MM-DD')
      };
    } else if (activeType === 'year') {
      newDates = {
        startTime: dayjs().startOf('year').format('YYYY-MM-DD'),
        endTime: dayjs().endOf('year').format('YYYY-MM-DD')
      };
    }

    setDates(newDates);
    // Don't include dates in the dependency array to avoid triggering this effect when dates change
  }, [activeType]);

  // Only notify changes when dates or activeType actually change
  useEffect(() => {
    // 只有当 dates 或 activeType 变化时才通知
    notifyChange();
  }, [dates, activeType]); // 明确指定依赖项
  // useEffect(() => {
  //   notifyChange();
  // }, [notifyChange]);

  const handleTypeChange = (type: DateType) => {
    if (type !== activeType) {
      setActiveType(type);
    }
  };

  const handleDateChange = (date: dayjs.Dayjs | null) => {
    if (!date) return;

    let newDates = { ...dates };
    
    if (activeType === 'day') {
      newDates = {
        startTime: date.format('YYYY-MM-DD'),
        endTime: date.format('YYYY-MM-DD')
      };
    } else if (activeType === 'month') {
      newDates = {
        startTime: date.startOf('month').format('YYYY-MM-DD'),
        endTime: date.endOf('month').format('YYYY-MM-DD')
      };
    } else if (activeType === 'year') {
      newDates = {
        startTime: date.startOf('year').format('YYYY-MM-DD'),
        endTime: date.endOf('year').format('YYYY-MM-DD')
      };
    }

    setDates(newDates);
  };

  const handleRangeChange = (dates: [dayjs.Dayjs | null, dayjs.Dayjs | null] | null) => {
    if (!dates || !dates[0] || !dates[1]) return;
    
    setDates({
      startTime: dates[0].format('YYYY-MM-DD'),
      endTime: dates[1].format('YYYY-MM-DD')
    });
  };

  const customSuffixIcon = <div className={styles.arrowIcon} />;

  // Determine date picker class names
  const datePickerClasses = classNames(
    styles.datePicker,
    styles.rangePickerStyle, 
    { [styles.active]: activeType === 'range' }
  );

  return (
    <div className={styles.container}>
      <div className={styles.buttonGroup}>
        <div 
          className={classNames(styles.button, { [styles.active]: activeType === 'day' })}
          onClick={() => handleTypeChange('day')}
        >
          日
        </div>
        <div 
          className={classNames(styles.button, { [styles.active]: activeType === 'month' })}
          onClick={() => handleTypeChange('month')}
        >
          月
        </div>
        <div 
          className={classNames(styles.button, { [styles.active]: activeType === 'year' })}
          onClick={() => handleTypeChange('year')}
        >
          年
        </div>
        {/* <div 
          className={classNames(styles.button, { [styles.active]: activeType === 'range' })}
          onClick={() => handleTypeChange('range')}
        >
          范围
        </div> */}
      </div>      
      
      <div className={styles.dateSelector} onClick={() => handleTypeChange('range')}>
        <ConfigProvider
          theme={{
            components: {
              DatePicker: {
                // 设置日期选择器背景为透明
                colorBgContainer: 'rgba(50, 102, 167, 0.5)',
                // 设置文本颜色为白色
                colorText: '#ffffff',
                // 设置占位符文本颜色为半透明白色
                colorTextPlaceholder: 'rgba(255, 255, 255, 0.5)',
                // 设置弹出面板背景为深蓝色
                colorBgElevated: '#0C1B3A',
                // 设置边框颜色为透明
                colorBorder: 'transparent',
                // 设置字体大小为16px
                fontSize: 16,
                // 设置内边距为22px
                paddingInline: 22,
                // 设置控件高度为36px
                controlHeight: 36,
                // 设置图标颜色为白色
                colorIcon: '#ffffff',
                // 设置图标hover状态颜色为亮蓝色
                colorIconHover: 'rgb(28, 192, 255)',
                // 设置禁用状态文本颜色为半透明白色
                colorTextDisabled: 'rgba(255, 255, 255, 0.25)',
                // 设置日期范围hover背景为半透明蓝色
                cellHoverWithRangeBg: 'rgba(39, 152, 214, 0.1)',
                // 设置主色调为亮蓝色
                colorPrimary: 'rgb(28, 192, 255)',
                // 设置主色调hover状态为浅蓝色
                colorPrimaryHover: 'rgb(82, 148, 255)',
                // 设置圆角为25px
                borderRadius: 25,
              },
            }
          }}
        >
          <DatePicker.RangePicker 
            allowClear={false}
            value={[dayjs(dates.startTime), dayjs(dates.endTime)]}
            onChange={handleRangeChange}
            format="YYYY-MM-DD"
            className={datePickerClasses}
            suffixIcon={customSuffixIcon}
            popupClassName={styles.datePickerDropdown}
          />
        </ConfigProvider>
      </div>

      <div className={styles.confirmButton}>确定</div>
    </div>
  );
};

export default DateSelector; 